@@ -16,14 +16,12 @@ module Serverspec::Type
     end
 
     def inspection
-      return @inspection if @inspection
-      @inspection = ::MultiJson.load(get_inspection.stdout)[0]
+      @inspection ||= ::MultiJson.load(get_inspection.stdout)[0]
     end
 
     private
     def get_inspection
-      return @get_inspection if @get_inspection
-      @get_inspection = @runner.run_command("docker inspect #{@name}")
+      @get_inspection ||= @runner.run_command("docker inspect #{@name}")
     end
   end
 end
